@@ -4,7 +4,7 @@ import pytest
 
 from owslib.wfs import WebFeatureService
 
-SERVICE_URL = 'http://geo.kralidis.ca/pygeoapi'
+SERVICE_URL = 'https://demo.pygeoapi.io/master'
 
 
 @pytest.mark.online
@@ -13,15 +13,21 @@ SERVICE_URL = 'http://geo.kralidis.ca/pygeoapi'
 def test_wfs3_pygeoapi():
     w = WebFeatureService(SERVICE_URL, version='3.0')
 
-    assert w.url == 'http://geo.kralidis.ca/pygeoapi/'
+    assert w.url == 'https://demo.pygeoapi.io/master/'
     assert w.version == '3.0'
     assert w.url_query_string is None
 
+    api = w.api()
+    assert api['components']['parameters'] is not None
+    paths = api['paths']
+    assert paths is not None
+    assert paths['/collections/lakes'] is not None
+
     conformance = w.conformance()
     assert len(conformance['conformsTo']) == 4
 
     collections = w.collections()
-    assert len(collections) == 3
+    assert len(collections) > 0
 
     lakes = w.collection('lakes')
     assert lakes['name'] == 'lakes'
